@@ -8,3 +8,5 @@ set_project_slug = _settings.set_project_slug
 set_request_permission_prompt = _settings.set_request_permission_prompt
 set_debug = _settings.set_debug
 set_noninteractive_tracking = _settings.set_noninteractive_tracking
+set_user_id = _settings.set_user_id
+set_invocation_id = _settings.set_invocation_id
